[TEST1]
{table}:{login}:{password}
[/TEST1]

[/TEST2]
{table}:{login}:{password}
[/TEST2]

[/TEST3]
{table}:{login}:{password}
[TEST3]

[TEST4]
{table}:{login}:{password}
[TEST4]

[\TEST5]
{table}:{login}:{password}
[\TEST5]

[TEST6]
{table}:{login}:{password}
[/TEST8]


dsadasasdasadasdasd
[TEST7]{table}:{login}:{password}[/TEST7]


[TEST10]
{table}:{login}:{password}:{email}
[/TEST10]

